@@ -196,7 +196,7 @@ has uid =>
 	required => 0,
 );
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 # ------------------------------------------------
 
@@ -1051,7 +1051,7 @@ Default: None.
 
 =item o length => $integer
 
-The maxiumum length of the input string to process.
+The maximum length of the input string to process.
 
 This parameter works in conjunction with the C<pos> parameter.
 
@@ -1172,13 +1172,13 @@ This is the default value.
 
 =item o 1/-1 => "Last open delimiter: $lexeme_1. Unexpected closing delimiter: $lexeme_2"
 
-If L</error_number()> returns 1, it's an error, and if it returns -1 it's a warning.
+If L</error_number()> returns 1 it's an error, and if it returns -1 it's a warning.
 
 You can set the option C<overlap_is_fatal> to make it fatal.
 
 =item o 2/-2 => "Opened delimiter $lexeme again before closing previous one"
 
-If L</error_number()> returns 2, it's an error, and if it returns -2 it's a warning.
+If L</error_number()> returns 2 it's an error, and if it returns -2 it's a warning.
 
 You can set the option C<nesting_is_fatal> to make it fatal.
 
@@ -1186,7 +1186,7 @@ You can set the option C<nesting_is_fatal> to make it fatal.
 
 This message is only produced when the parse is ambiguous.
 
-If L</error_number()> returns 3, it's an error, and if it returns -3 it's a warning.
+If L</error_number()> returns 3 it's an error, and if it returns -3 it's a warning.
 
 You can set the option C<ambiguity_is_fatal> to make it fatal.
 
@@ -1194,18 +1194,18 @@ You can set the option C<ambiguity_is_fatal> to make it fatal.
 
 This preempts some types of sabotage.
 
-This message can never be just a warning message.
+This message always indicates an error, never a warning.
 
 =item o 5 => "Single-quotes are forbidden in multi-character delimiters"
 
 This limitation is due to the syntax of
 L<Marpa's DSL|https://metacpan.org/pod/distribution/Marpa-R2/pod/Scanless/DSL.pod>.
 
-This message can never be just a warning message.
+This message always indicates an error, never a warning.
 
 =item o 6/-6 => "Parse exhausted"
 
-If L</error_number()> returns 6, it's an error, and if it returns -6 it's a warning.
+If L</error_number()> returns 6 it's an error, and if it returns -6 it's a warning.
 
 You can set the option C<exhaustion_is_fatal> to make it fatal.
 
@@ -1214,28 +1214,28 @@ You can set the option C<exhaustion_is_fatal> to make it fatal.
 This limitation is due to the syntax of
 L<Marpa's DSL|https://metacpan.org/pod/distribution/Marpa-R2/pod/Scanless/DSL.pod>.
 
-This message can never be just a warning message.
+This message always indicates an error, never a warning.
 
 =item o 8 => "There must be at least 1 pair of open/close delimiters"
 
-This message can never be just a warning message.
+This message always indicates an error, never a warning.
 
 =item o 9 => "The # of open delimiters must match the # of close delimiters"
 
-This message can never be just a warning message.
+This message always indicates an error, never a warning.
 
 =item o 10 => "Unexpected event name 'xyz'"
 
-Marpa has trigged an event and it's name is not in the hash of event names derived from the BNF.
+Marpa has triggered an event and it's name is not in the hash of event names derived from the BNF.
 
-This message can never be just a warning message.
+This message always indicates an error, never a warning.
 
 =item o 11 => "The code does not handle these events simultaneously: a, b, ..."
 
 The code is written to handle single events at a time, or in rare cases, 2 events at the same time.
 But here, multiple events have been triggered and the code cannot handle the given combination.
 
-This message can never be just a warning message.
+This message always indicates an error, never a warning.
 
 =back
 
@@ -1626,7 +1626,7 @@ See scripts/traverse.pl. It is a copy of t/html.t with tree-walking code instead
 The parsed output is held in a tree managed by L<Tree>.
 
 The tree always has a root node, which has nothing to do with the input data. So, even an empty
-imput string will produce a tree with 1 node. This root has an empty hashref associated with it.
+input string will produce a tree with 1 node. This root has an empty hashref associated with it.
 
 Nodes have a name and a hashref of attributes.
 
