@@ -7,21 +7,23 @@ use Text::Balanced::Marpa;
 
 # -----------
 
-my($count)  = 0;
+my(%count)  = (fail => 0, success => 0, total => 0);
 my($parser) = Text::Balanced::Marpa -> new
 (
-	open  => ['{'],
-	close => ['}'],
+	open  => ['<:'],
+	close => [':>'],
 );
 my(@prefix) =
 (
+	'',
 	'Skip me ->',
 	"I've already parsed up to here ->",
 );
 my(@text) =
 (
-	q|a {b} c {|,
-	q|a {b {c} d} e|,
+	q|<:a:> <:b:>|,
+	q|a <:b <:c:> d:> e <:f <: g <:h:> i:> j:> k|,
+	q|one <: two <: three <: four :> five :> six :> seven|,
 );
 
 my($result);
@@ -29,14 +31,14 @@ my($text);
 
 for my $i (0 .. $#text)
 {
-	$count++;
+	$count{total}++;
 
 	$text = $prefix[$i] . $text[$i];
 
 	$parser -> pos(length $prefix[$i]);
 	$parser -> length(length($text) - $parser -> pos);
 
-	print '        | ';
+	print sprintf('(# %3d) | ', $count{total});
 	printf '%10d', $_ for (1 .. 9);
 	print "\n";
 	print '        |';
@@ -46,6 +48,17 @@ for my $i (0 .. $#text)
 
 	$result = $parser -> parse(text => \$text);
 
-	print join("\n", @{$parser -> tree -> tree2string}), "\n";
 	print "Parse result: $result (0 is success)\n";
+
+	if ($result == 0)
+	{
+		$count{success}++;
+
+		print join("\n", @{$parser -> tree -> tree2string}), "\n";
+	}
 }
+
+$count{fail} = $count{total} - $count{success};
+
+print "\n";
+print 'Statistics: ', join(', ', map{"$_ => $count{$_}"} sort keys %count), ". \n";
